class UIScreenListener_UnbindMods_UISaveGame extends UIScreenListener;

var UIMovie Movie;
var UISaveGame ParentScreen;
var String ScreenToUse;
var bool bUseBackupSpawningMethod;
var bool bShowInTactical;

event OnInit(UIScreen Screen)
{
	local UIButton UMMButton;

	ScreenToUse=class'RemoveMissingModsSettings'.static.GetScreenToUse();
	bUseBackupSpawningMethod=class'RemoveMissingModsSettings'.static.GetUseBackupSpawningMethod();
	bShowInTactical=class'RemoveMissingModsSettings'.static.GetShowInTactical();
	
	if(bUseBackupSpawningMethod)
	{
		if((ScreenToUse=="SaveScreen" && IsStrategyState()) || (ScreenToUse=="SaveScreen" && bShowInTactical))
		{
			`log("Spawning Button on"@ScreenToUse@"Using Backup Method");
			`log("ShowInTactical is" @bShowInTactical);

			ParentScreen = UISaveGame(Screen);
			Movie = Screen.Movie;

			UMMButton = Screen.Spawn(class 'UIButton', Screen);

			UMMButton.InitButton(, "Unbind Missing Mods and Save", OnUnbind);
			UMMButton.SetPosition(375, 50);
		}
	}
}

function bool IsStrategyState()
{
    return `HQGAME  != none && `HQPC != None && `HQPRES != none;
}

public function OnUnbind(UIButton UMMButton)
{
	local TDialogueBoxData DialogData;

	DialogData.eType       =  eDialog_Warning;
	DialogData.strTitle    = "Remove bindings for missing Mods and create new save?";
	DialogData.strText     = "This will remove any mod not currently loaded from the list of required mods, including itself, and create a new Save.";
	DialogData.strAccept   = "Accept"; 
	DialogData.strCancel   = "Cancel"; 
	DialogData.fnCallback  =  UnbindMissingMods;

	Movie.Pres.UIRaiseDialog(DialogData);
}

function UnbindMissingMods(name eAction)
{
	local XComGameState NewGameState;
	local XComGameStateHistory History;
	local XComGameState_CampaignSettings CampaignSettingsStateObject;
	local int i;
	local name DLCName, RemoveMissingMods;
	local TDialogueBoxData kDialogData;

	Movie.Pres.PlayUISound(eSUISound_MenuSelect);

	History = `XCOMHISTORY;
	RemoveMissingMods=name("WOTC_RemoveMissingMods");
	
	if (eAction == 'eUIAction_Accept')
	{
		NewGameState = class'XComGameStateContext_ChangeContainer'.static.CreateChangeState("Removing Missing Mods");

		CampaignSettingsStateObject = XComGameState_CampaignSettings(History.GetSingleGameStateObjectForClass(class'XComGameState_CampaignSettings', true));
		CampaignSettingsStateObject = XComGameState_CampaignSettings(NewGameState.ModifyStateObject(class'XComGameState_CampaignSettings', CampaignSettingsStateObject.ObjectID));
		
		CampaignSettingsStateObject.RemoveAllRequiredDLC();
		
		for(i = 0; i < `ONLINEEVENTMGR.GetNumDLC(); ++i)
		{
			DLCName = `ONLINEEVENTMGR.GetDLCNames(i);
			if(CampaignSettingsStateObject.RequiredDLC.Find(DLCName) == -1 && DLCName!=RemoveMissingMods)
			{
				CampaignSettingsStateObject.AddRequiredDLC(DLCName);
			}
		}
		`GAMERULES.SubmitGameState(NewGameState);

		if(ParentScreen.m_iCurrentSelection > 0 )
		{
			// Warn about overwriting an existing save
			kDialogData.eType     = eDialog_Warning;
			kDialogData.strTitle  = ParentScreen.m_sOverwriteSaveTitle;
			kDialogData.strText   = ParentScreen.m_sOverwriteSaveText;
			kDialogData.strAccept = class'UIDialogueBox'.default.m_strDefaultAcceptLabel;
			kDialogData.strCancel = class'UIDialogueBox'.default.m_strDefaultCancelLabel;

			kDialogData.fnCallback  = ParentScreen.OverwritingSaveWarningCallback;
			Movie.Pres.UIRaiseDialog( kDialogData );
		}
		else
		{
			// Saving into an empty slot
			`ONLINEEVENTMGR.SetPlayerDescription(ParentScreen.GetCurrentSelectedFilename());
			ParentScreen.Save();
		}
	}
}

defaultproperties
{
	ScreenClass = class'UISaveGame';
}